pub struct AddIdentityBuilder { /* private fields */ }Expand description
Instruction builder for AddIdentity.
Accounts:
[]mint[]token_account[writable]policy[writable, signer]payer[writable, signer]owner[optional]system_program (default to11111111111111111111111111111111)
Implementations
Sourceimpl AddIdentityBuilder
impl AddIdentityBuilder
pub fn new() -> Self
Sourcepub fn mint(&mut self, mint: Pubkey) -> &mut Self
pub fn mint(&mut self, mint: Pubkey) -> &mut Self
The token extensions mint account linked to the policy
Sourcepub fn token_account(&mut self, token_account: Pubkey) -> &mut Self
pub fn token_account(&mut self, token_account: Pubkey) -> &mut Self
The authority over the policy based on token ownership of the mint
Sourcepub fn system_program(&mut self, system_program: Pubkey) -> &mut Self
pub fn system_program(&mut self, system_program: Pubkey) -> &mut Self
[optional account, default to '11111111111111111111111111111111']
The system program
pub fn identity(&mut self, identity: Pubkey) -> &mut Self
Sourcepub fn add_remaining_account(&mut self, account: AccountMeta) -> &mut Self
pub fn add_remaining_account(&mut self, account: AccountMeta) -> &mut Self
Add an additional account to the instruction.
Sourcepub fn add_remaining_accounts(&mut self, accounts: &[AccountMeta]) -> &mut Self
pub fn add_remaining_accounts(&mut self, accounts: &[AccountMeta]) -> &mut Self
Add additional accounts to the instruction.
pub fn instruction(&self) -> Instruction