pub struct AddIdentityCpi<'a, 'b> {
pub __program: &'b AccountInfo<'a>,
pub mint: &'b AccountInfo<'a>,
pub token_account: &'b AccountInfo<'a>,
pub policy: &'b AccountInfo<'a>,
pub payer: &'b AccountInfo<'a>,
pub owner: &'b AccountInfo<'a>,
pub system_program: &'b AccountInfo<'a>,
pub __args: AddIdentityInstructionArgs,
}Expand description
add_identity CPI instruction.
Fields
__program: &'b AccountInfo<'a>The program to invoke.
mint: &'b AccountInfo<'a>The token extensions mint account linked to the policy
token_account: &'b AccountInfo<'a>The authority over the policy based on token ownership of the mint
policy: &'b AccountInfo<'a>The shield policy account
payer: &'b AccountInfo<'a>The account paying for the storage fees
owner: &'b AccountInfo<'a>The owner of the token account
system_program: &'b AccountInfo<'a>The system program
__args: AddIdentityInstructionArgsThe arguments for the instruction.
Implementations
Sourceimpl<'a, 'b> AddIdentityCpi<'a, 'b>
impl<'a, 'b> AddIdentityCpi<'a, 'b>
pub fn new( program: &'b AccountInfo<'a>, accounts: AddIdentityCpiAccounts<'a, 'b>, args: AddIdentityInstructionArgs, ) -> Self
pub fn invoke(&self) -> ProgramResult
pub fn invoke_with_remaining_accounts( &self, remaining_accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> ProgramResult
pub fn invoke_signed(&self, signers_seeds: &[&[&[u8]]]) -> ProgramResult
pub fn invoke_signed_with_remaining_accounts( &self, signers_seeds: &[&[&[u8]]], remaining_accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> ProgramResult