pub struct AddIdentityCpiAccounts<'a, 'b> {
pub mint: &'b AccountInfo<'a>,
pub token_account: &'b AccountInfo<'a>,
pub policy: &'b AccountInfo<'a>,
pub payer: &'b AccountInfo<'a>,
pub owner: &'b AccountInfo<'a>,
pub system_program: &'b AccountInfo<'a>,
}Expand description
add_identity CPI accounts.
Fields
mint: &'b AccountInfo<'a>The token extensions mint account linked to the policy
token_account: &'b AccountInfo<'a>The authority over the policy based on token ownership of the mint
policy: &'b AccountInfo<'a>The shield policy account
payer: &'b AccountInfo<'a>The account paying for the storage fees
owner: &'b AccountInfo<'a>The owner of the token account
system_program: &'b AccountInfo<'a>The system program