pub struct AddIdentityInstructionArgs {
pub identity: Pubkey,
}Fields
identity: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for AddIdentityInstructionArgs
impl BorshDeserialize for AddIdentityInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for AddIdentityInstructionArgs
impl Clone for AddIdentityInstructionArgs
Sourcefn clone(&self) -> AddIdentityInstructionArgs
fn clone(&self) -> AddIdentityInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AddIdentityInstructionArgs
impl Debug for AddIdentityInstructionArgs
impl Eq for AddIdentityInstructionArgs
impl StructuralPartialEq for AddIdentityInstructionArgs