pub struct CreatePolicy {
pub mint: Pubkey,
pub token_account: Pubkey,
pub policy: Pubkey,
pub payer: Pubkey,
pub owner: Pubkey,
pub system_program: Pubkey,
}Expand description
Accounts.
Fields
mint: PubkeyThe token extensions mint account linked to the policy
token_account: PubkeyThe authority over the policy based on token ownership of the mint
policy: PubkeyThe shield policy account
payer: PubkeyThe account paying for the storage fees
owner: PubkeyThe owner of the token account
system_program: PubkeyThe system program
Implementations
Sourceimpl CreatePolicy
impl CreatePolicy
pub fn instruction(&self, args: CreatePolicyInstructionArgs) -> Instruction
pub fn instruction_with_remaining_accounts( &self, args: CreatePolicyInstructionArgs, remaining_accounts: &[AccountMeta], ) -> Instruction