pub struct RemoveIdentity {
pub mint: Pubkey,
pub token_account: Pubkey,
pub policy: Pubkey,
pub owner: Pubkey,
}Expand description
Accounts.
Fields
mint: PubkeyThe token extensions mint account linked to the policy
token_account: PubkeyThe authority over the policy based on token ownership of the mint
policy: PubkeyThe shield policy account
owner: PubkeyThe owner of the token account
Implementations
Sourceimpl RemoveIdentity
impl RemoveIdentity
pub fn instruction(&self, args: RemoveIdentityInstructionArgs) -> Instruction
pub fn instruction_with_remaining_accounts( &self, args: RemoveIdentityInstructionArgs, remaining_accounts: &[AccountMeta], ) -> Instruction